@@ -12,6 +12,7 @@ use bevy::prelude::*;
 
 #[cfg(feature = "collision-from-mesh")]
 pub use collision_from_mesh::PendingConvexCollision;
+pub use collisions::Collisions;
 pub use constraints::RotationConstraints;
 pub use events::{CollisionData, CollisionEvent};
 pub use gravity::Gravity;
@@ -22,6 +23,7 @@ pub use velocity::{Acceleration, AxisAngle, Damping, Velocity};
 
 #[cfg(feature = "collision-from-mesh")]
 mod collision_from_mesh;
+mod collisions;
 mod constraints;
 mod events;
 mod gravity;
@@ -76,6 +78,9 @@ impl Plugin for CorePlugin {
             .register_type::<RotationConstraints>()
             .register_type::<CollisionLayers>()
             .register_type::<SensorShape>()
+            .register_type::<Collisions>()
+            .add_system(collisions::update_collisions_system)
+            .add_system_to_stage(CoreStage::PostUpdate, collisions::cleanup_collisions_system)
             .add_system_to_stage(CoreStage::First, PhysicsSteps::update)
             .add_stage_before(CoreStage::PostUpdate, crate::stage::ROOT, {
                 Schedule::default().with_stage(crate::stage::UPDATE, SystemStage::parallel())
